@@ -1,5 +1,5 @@
-#ifndef _JSON_H_
-#define _JSON_H_
+#ifndef JSON_H
+#define JSON_H
 
 #include <stddef.h>
 
@@ -26,5 +26,5 @@ struct json_node {
 	size_t index; /* count/index for array or object type */
 };
 
-int parsejson(void (*cb)(struct json_node *, size_t, const char *));
+int parsejson(void (*cb)(struct json_node *, size_t, const char *, size_t));
 #endif
